RoutingService class abstract
High-level service for computing routes and turn-by-turn directions.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getDirections(
Route route, {MapProvider? provider}) → Future< List< DirectionStep> > -
Returns turn-by-turn DirectionSteps for
route. -
getRoute(
Coordinates origin, Coordinates destination, {MapProvider? provider}) → Future< Route> -
Returns a Route between
originanddestination. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited